package com.ruoyi.biz.controller;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.biz.domain.vo.ArFileBannerVo;
import com.ruoyi.biz.domain.bo.ArFileBannerBo;
import com.ruoyi.biz.service.IArFileBannerService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 轮播图
 *
 * @author gwd
 * @date 2023-11-10
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/biz/fileBanner")
public class ArFileBannerController extends BaseController {

    private final IArFileBannerService iArFileBannerService;

    /**
     * 查询轮播图列表
     */
    @SaCheckPermission("biz:fileBanner:list")
    @GetMapping("/list")
    public TableDataInfo<ArFileBannerVo> list(ArFileBannerBo bo, PageQuery pageQuery) {
        return iArFileBannerService.queryPageList(bo, pageQuery);
    }

//    /**
//     * 导出轮播图列表
//     */
//    @SaCheckPermission("biz:fileBanner:export")
//    @Log(title = "轮播图", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(ArFileBannerBo bo, HttpServletResponse response) {
//        List<ArFileBannerVo> list = iArFileBannerService.queryList(bo);
//        ExcelUtil.exportExcel(list, "轮播图", ArFileBannerVo.class, response);
//    }

//    /**
//     * 获取轮播图详细信息
//     *
//     * @param id 主键
//     */
//    @SaCheckPermission("biz:fileBanner:query")
//    @GetMapping("/{id}")
//    public R<ArFileBannerVo> getInfo(@NotNull(message = "主键不能为空")
//                                     @PathVariable Long id) {
//        return R.ok(iArFileBannerService.queryById(id));
//    }

    /**
     * 新增轮播图
     */
    @SaCheckPermission("biz:fileBanner:add")
    @Log(title = "轮播图", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ArFileBannerBo bo) {
        return toAjax(iArFileBannerService.insertByBo(bo) ? 1 : 0);
    }

    /**
     * 修改轮播图
     */
    @SaCheckPermission("biz:fileBanner:edit")
    @Log(title = "轮播图", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ArFileBannerBo bo) {
        return toAjax(iArFileBannerService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除轮播图
     *
     * @param ids 主键串
     */
    @SaCheckPermission("biz:fileBanner:remove")
    @Log(title = "轮播图", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] ids) {
        return toAjax(iArFileBannerService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }
}
